[Pkg-owncloud-commits] [owncloud-client] 63/121: Share: Permissions for federated shares on servers >=9.1 #4996 (#5001)

Sandro Knauß hefee-guest at moszumanska.debian.org
Thu Jul 28 15:31:58 UTC 2016


This is an automated email from the git hooks/post-receive script.

hefee-guest pushed a commit to branch master
in repository owncloud-client.

commit bdb304f8ecb6c03b8600ee1ba153b952f96d35f3
Author: ckamm <mail at ckamm.de>
Date:   Mon Jun 27 11:09:51 2016 +0200

    Share: Permissions for federated shares on servers >=9.1 #4996 (#5001)
    
    This disables the workaround 487e1fdca5ee04fc98c1ed77898df70d740967c8
    for servers that are new enough to support fine grained permissions
    on federated shares.
    
    The consequence is that the 'reshare' permission is now granted by
    default and that users can edit permissions on the usual fine-grained
    level again.
    
    The way the client deals with servers <9.1 is unchanged.
---
 src/gui/shareusergroupwidget.cpp | 12 ++++++++----
 1 file changed, 8 insertions(+), 4 deletions(-)

diff --git a/src/gui/shareusergroupwidget.cpp b/src/gui/shareusergroupwidget.cpp
index a2b9a5d..b72de8c 100644
--- a/src/gui/shareusergroupwidget.cpp
+++ b/src/gui/shareusergroupwidget.cpp
@@ -248,10 +248,12 @@ void ShareUserGroupWidget::slotCompleterActivated(const QModelIndex & index)
     layout->addWidget(indicator);
 
     /*
-     * Don't send the reshare permissions for federataed shares
+     * Don't send the reshare permissions for federated shares for servers <9.1
      * https://github.com/owncloud/core/issues/22122#issuecomment-185637344
+     * https://github.com/owncloud/client/issues/4996
      */
-    if (sharee->type() == Sharee::Federated) {
+    if (sharee->type() == Sharee::Federated
+            && _account->serverVersionInt() < 0x090100) {
         int permissions = SharePermissionRead | SharePermissionUpdate;
         if (!_isFile) {
             permissions |= SharePermissionCreate | SharePermissionDelete;
@@ -335,10 +337,12 @@ ShareWidget::ShareWidget(QSharedPointer<Share> share,
     connect(_ui->permissionsEdit,  SIGNAL(clicked(bool)), SLOT(slotEditPermissionsChanged()));
 
     /*
      * We don't show permssion share for federated shares
      * https://github.com/owncloud/core/issues/22122#issuecomment-185637344
+     * https://github.com/owncloud/client/issues/4996
      */
-    if (share->getShareType() == Share::TypeRemote) {
+    if (share->getShareType() == Share::TypeRemote
+            && share->account()->serverVersionInt() < 0x090100) {
         _ui->permissionShare->setVisible(false);
         _ui->permissionToolButton->setVisible(false);
     }
@@ -335,10 +337,12 @@ ShareWidget::ShareWidget(QSharedPointer<Share> share,
 
     /*
-     * We don't show permssion share for federated shares
+     * We don't show permssion share for federated shares with server <9.1
      * https://github.com/owncloud/core/issues/22122#issuecomment-185637344

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud-client.git



More information about the Pkg-owncloud-commits mailing list